@@ -60,24 +60,28 @@ class ArchAMD64(Arch):
             self.registers['xmm6'][0]: 6,
             self.registers['xmm7'][0]: 7
         } if _pyvex is not None else None
-        if _unicorn:
-            self.unicorn_flag_register = _unicorn.x86_const.UC_X86_REG_EFLAGS
 
         # Register blacklist
         reg_blacklist = ('fs', 'gs')
-        for register in self.register_list:
-            if register.name in reg_blacklist:
-                self.reg_blacklist.append(register.name)
-                self.reg_blacklist_offsets.append(register.vex_offset)
+        if self.reg_blacklist is not None and self.reg_blacklist_offsets is not None:
+            for register in self.register_list:
+                if register.name in reg_blacklist:
+                    self.reg_blacklist.append(register.name)
+                    self.reg_blacklist_offsets.append(register.vex_offset)
 
-        # CPU flag registers
-        cpu_flag_registers = {'d': 10, 'ac': 18, 'id': 21}
-        self.cpu_flag_register_offsets_and_bitmasks_map = {}
-        for flag_reg, bitmask in cpu_flag_registers.items():
-            if flag_reg in self.registers:
-                flag_reg_offset = self.get_register_offset(flag_reg)
-                flag_bitmask = (1 << bitmask)
-                self.cpu_flag_register_offsets_and_bitmasks_map[flag_reg_offset] = flag_bitmask
+        if _unicorn and _pyvex:
+            # CPU flag registers
+            uc_flags_reg = _unicorn.x86_const.UC_X86_REG_EFLAGS
+            cpu_flag_registers = {"d": 1 << 10, "ac": 1 << 18, "id": 1 << 21}
+            for reg, reg_bitmask in cpu_flag_registers.items():
+                reg_offset = self.get_register_offset(reg)
+                self.cpu_flag_register_offsets_and_bitmasks_map[reg_offset] = (uc_flags_reg, reg_bitmask)
+
+            mxcsr_registers = {"sseround": 1 << 14 | 1 << 13}
+            uc_mxcsr_reg = _unicorn.x86_const.UC_X86_REG_MXCSR
+            for reg, reg_bitmask in mxcsr_registers.items():
+                reg_offset = self.get_register_offset(reg)
+                self.cpu_flag_register_offsets_and_bitmasks_map[reg_offset] = (uc_mxcsr_reg, reg_bitmask)
 
     @property
     def capstone_x86_syntax(self):
@@ -252,7 +256,7 @@ class ArchAMD64(Arch):
                  general_purpose=True),
         Register(name='ac', size=8, alias_names=('acflag',),concrete=False),
         Register(name='id', size=8, alias_names=('idflag',)),
-        Register(name='fs', size=8, alias_names=('fs_const',),
+        Register(name='fs', size=8, vex_name='fs_const', alias_names=('fs_const',),
                  default_value=(0x9000000000000000, True, 'global'),concrete=False),
         Register(name='sseround', size=8, vector=True,
                  default_value=(0, False, None)),
@@ -359,8 +363,14 @@ class ArchAMD64(Arch):
         Register(name='cmstart', size=8),
         Register(name='cmlen', size=8),
         Register(name='nraddr', size=8),
-        Register(name='gs', size=8, alias_names=('gs_const',), concrete=False),
+        Register(name='gs', size=8, vex_name='gs_const', alias_names=('gs_const',), concrete=False),
         Register(name='ip_at_syscall', size=8, concrete=False, artificial=True),
+        Register(name='cs_seg', size=2, vex_name='cs'),
+        Register(name='ds_seg', size=2, vex_name='ds'),
+        Register(name='es_seg', size=2, vex_name='es'),
+        Register(name='fs_seg', size=2, vex_name='fs'),
+        Register(name='fs_seg', size=2, vex_name='gs'),
+        Register(name='ss_seg', size=2, vex_name='ss'),
     ]
 
     symbol_type_translation = {
